# Release notes for MUSE v1.5.5 (March 27, 2026)

This release has no changes to the code, but fixes an issue affecting new installations
of MUSE due to incompatibility with the latest major version of `pandas` (3.0.0), which
was released on January 21, 2026.

The next major version of MUSE1 (v1.6.0) will include support for `pandas` 3.0.0, as
well as dropping support for Python 3.9 and 3.10. In the meantime, new users should
install MUSE v1.5.5 to ensure that a compatible version of `pandas` is being used.
